using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Drawing;
using System.Drawing.Drawing2D;

using Syncfusion.Web.UI;
using Syncfusion.Web.UI.WebControls.Chart;
using Syncfusion.Windows.Forms.Chart;
using Syncfusion.Drawing;

public partial class _Default : System.Web.UI.Page 
{
    protected void Page_Load(object sender, EventArgs e)
    {
      this.InitializeChartData(true);
      this.InitializeChartSettings();
      this.InitializeControlSettings();
    }

  private void InitializeControlSettings()
  {
    // Specify a ChartPalette:
    Color[] color = new Color[] { Color.FromArgb(185, 73, 141, 238), Color.FromArgb(185, 247, 179, 78), Color.FromArgb(185, 186, 66, 30) };
    this.ChartWebControl1.Palette = ChartColorPalette.Custom;
    this.ChartWebControl1.Model.ColorModel.CustomColors = color;
    this.ChartWebControl1.Palette = ChartColorPalette.Custom;

    //this.ChartWebControl1.ChartInterior = new Syncfusion.Drawing.BrushInfo(185, new Syncfusion.Drawing.BrushInfo(Syncfusion.Drawing.GradientStyle.Vertical, Color.LightBlue, Color.Azure));
    this.ChartWebControl1.LegendPosition = ChartDock.Top;
    this.ChartWebControl1.ChartWebArea.HidePartialLabels = false;
  }

  protected void InitializeChartSettings()
  {
    this.ChartWebControl1.AutoTempFileCleanUp = true;

    /*
    You can set the ouput format to ImageProviderOutputFormat.DiskFile to tell the chart to generate
    disk files instead of using handlers. Handlers are better since they do not generate any
    disk files. The ImageURLPath controls where disk files are stored if OutputFormat.DiskFile
    is used. Please note that user "ASPNET" will need to have write permissions to this folder
    on your server. If write permission is not provided the chart will not be able to write to disk. 		
    //this.ChartWebControl1.ImageUrlPath = ".\\TempImages";
    */

    this.ChartWebControl1.OutputFormat = ImageProviderOutputFormat.Handler;


  }

  protected void InitializeChartData(bool clear)
  {

    if (clear)
      this.ChartWebControl1.Model.Series.Clear();

    ChartSeries series1 = this.ChartWebControl1.Model.NewSeries(" Server 1", ChartSeriesType.Spline);
    series1.Text = series1.Name;
    DateTime date = DateTime.Now;

    series1.Points.Add(date, 46);
    series1.Points.Add(date.AddMonths(1), 50);
    series1.Points.Add(date.AddMonths(2), 55);
    series1.Points.Add(date.AddMonths(3), 70);
    series1.Points.Add(date.AddMonths(4), 73);
    series1.Points.Add(date.AddMonths(5), 76);
    series1.Points.Add(date.AddMonths(6), 85);
    series1.Points.Add(date.AddMonths(7), 97);
    series1.Points.Add(date.AddMonths(8), 78);

    this.ChartWebControl1.PrimaryXAxis.ValueType = ChartValueType.DateTime;
    this.ChartWebControl1.PrimaryXAxis.RangeType = ChartAxisRangeType.Set;
    this.ChartWebControl1.PrimaryXAxis.DateTimeRange = new ChartDateTimeRange(date.AddMonths(-2), date.AddMonths(10), 1, ChartDateTimeIntervalType.Months);
    this.ChartWebControl1.PrimaryXAxis.DateTimeFormat = "MMM yy";
    this.ChartWebControl1.PrimaryXAxis.LabelRotate = true;
    this.ChartWebControl1.PrimaryXAxis.LabelRotateAngle = 90;
    this.ChartWebControl1.Text = "Essential Chart - Daily Server Load";
    this.ChartWebControl1.PrimaryYAxis.Title = "Server Load (MBytes)";

    series1.PrepareStyle += new ChartPrepareStyleInfoHandler(ChartControlSeries_PrepareStyle);

    this.ChartWebControl1.Series.Add(series1);

    // This is to set the axis size to change the series width which is attached to it
    this.ChartWebControl1.Model.Series[0].ActualXAxis.AutoSize = false;
    this.ChartWebControl1.Model.Series[0].ActualXAxis.Size = new SizeF(200, 1);

    //this.ChartWebControl1.PrimaryXAxis.AutoSize = false;
    //this.ChartWebControl1.PrimaryXAxis.Size = new SizeF(200, 1);
  }

  protected void ChartControlSeries_PrepareStyle(object sender, ChartPrepareStyleInfoEventArgs args)
  {
    // Style formatting using a callback. You can apply the same settings directly on the series style on the
    // point styles.
    ChartSeries series = sender as ChartSeries;
    series.EnableStyles = true;

    if (series != null)
    {
      args.Style.DisplayText = true;
      args.Style.TextFormat = "{0}";
      args.Style.TextOffset = 15;

      if (series == this.ChartWebControl1.Model.Series[0])
        args.Style.TextOrientation = ChartTextOrientation.Up;
      else
        args.Style.TextOrientation = ChartTextOrientation.Right;

      args.Style.Symbol.Shape = ChartSymbolShape.Square;
      args.Style.Symbol.Size = new Size(5, 5);
      
      // This property is to change the color of the symbol on the Line
      args.Style.Symbol.Color = Color.DarkCyan;

      // This property is to change the color of the Line
      args.Style.Interior = new BrushInfo(Color.White);
      
      args.Style.DisplayShadow = true;
    }
  }
}
